# shyna/shynais



## Getting Started

Download links:

SSH clone URL: ssh://git@git.jetbrains.space/shyna623/shyna/shynais.git

HTTPS clone URL: https://git.jetbrains.space/shyna623/shyna/shynais.git



These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

## Prerequisites

What things you need to install the software and how to install them.

```
    "setuptools",
    "wheel",
    "ShynaDatabase",
    "ShynaWeather",
    "Shynatime",
    "python-telegram-bot",
    "ShynaTelegramBotNotification",
    "wget",
    "haversine"
```

## Deployment

Add additional notes about how to deploy this on a production system.

## Resources

Add links to external resources for this project, such as CI server, bug tracker, etc.

## Description

```
    This is for tracking and checking activities. It will store the data in table
    and Notification package should take care of sending notification in case there is something unexpected
    1) is_location_service_on?
    2) is_this_is_first_time_on_cam?
    3) is_shivam_in_front_of _any_camera?
    4) is_shivam_working late night?
    5) Is_shivam_at_home?
    6) is_mom_calling?
    7) is_shivam_far_away?
    8) is_shivam_coming_home?
    

```